

local moduleName = "Agro"



----------------------------
--      Localization      --
----------------------------

local L = AceLibrary("AceLocale-2.2"):new("BunchOfBars"..moduleName)

L:RegisterTranslations("enUS", function() return {
	[moduleName] = "Agro Monitor",

	["Check frequency"] = true,
	["Frequency in seconds."] = true
} end)



----------------------------------
--      Local Declaration      --
----------------------------------



----------------------------------
--      Module Declaration      --
----------------------------------

local plugin = BunchOfBars:NewModule(moduleName, "AceEvent-2.0")

plugin.options = {
	name = L[moduleName],
	args = {
		frequency = {
			type = "range",
			name = L["Check frequency"],
			desc = L["Frequency in seconds."],
			min = 0.1,
            max = 2.0,
            step = 0.1,
            get = "GetSetFrequency",
            set = "GetSetFrequency",
		}
	}
}

plugin.defaultDB = {
	frequency = 0.5
}


plugin.agro = {} -- can't be local since other modules need access



----------------------------------
--      Module Functions        --
----------------------------------

function plugin:OnEnable()
	self:ScheduleRepeatingEvent("BunchOfBars_AgroUpdate", self.Update, self.db.profile.frequency, self)
end


function plugin:Update()
	for k in pairs(self.agro) do
		self.agro[k] = self.agro[k] - self.db.profile.frequency

		if self.agro[k] < 0 then
			self.agro[k] = nil
		end
	end

	for unit in pairs(self.core.frames) do
		if UnitExists(unit.."target") and 
			UnitIsEnemy(unit.."target", "player") and 
			UnitExists(unit.."targettarget") then
			
			if UnitIsUnit(unit.."targettarget", "player") and not self.agro[UnitName("player")] then
				-- PlaySound(...)
			end

			self.agro[UnitName(unit.."targettarget")] = 1.5
		end
	end
end


function plugin:GetSetFrequency(value)
	if type(value) == "nil" then return self.db.profile.frequency end

	-- this check is to assure we don't reschedule the event to often
	if self.db.profile.frequency ~= value then
		self.db.profile.frequency = value

		self:OnEnable()
	end
end
